import { Chunk } from './сhunk';
import { Table, ChunkId } from './interface';
/**
 * Class representing a pool for row chunks
 * This pool abstraction let us to create any kind of strategies to insert chunks
 */
export declare abstract class ChunkPool {
    ttlMs: number;
    maxSize: number;
    constructor();
    /**
     * Setter
     * time for chunk to be unblocked and alive for assumming new table rows
     *
     * @param {number} ttlMs
     */
    setTtlMs(ttlMs: number): void;
    /**
     * Getter
     * time for chunk to be unblocked and alive for assumming new table rows
     *
     * @returns {number}
     */
    getTtlMs(): number;
    /**
     * Setter
     * total count of rows can be collected in a single table chunk before being blocked and resolved
     *
     * @param {number} maxSize
     */
    setMaxSize(maxSize: number): void;
    /**
     * Getter
     * total count of rows can be collected in a single table chunk before being blocked and resolved
     *
     * @returns {number}
     */
    getMaxSize(): number;
    /**
     * Appending some chunk to a table chunk registry
     *
     * @param {Table} table
     * @param {Chunk} chunk
     */
    abstract appendChunk(table: Table, chunk: Chunk): void;
    /**
     * Remove some single chunk from registry
     *
     * @param {Table} table
     * @param {ChunkId} id
     */
    abstract removeChunk(table: Table, id: ChunkId): void;
    /**
     * Remove many chunks from registry
     *
     * @param {Table} table
     * @param {ChunkId[]} ids
     */
    abstract removeChunks(table: Table, ids: ChunkId[]): void;
    /**
     * Get table chunks as a snapshot
     *
     * @param {Table} table
     * @returns {Chunk[]}
     */
    abstract getChunks(table: Table): Chunk[];
    /**
     * Get list of tables which are represented in Pool registry
     *
     * @returns {Table[]}
     */
    abstract getTables(): Table[];
    /**
     * Get already existing or new chunk
     *
     * @param {Table} table
     *
     * @returns {Chunk}
     */
    abstract getUnblockedChunk(table: Table): Chunk;
}
