import { Chunk } from '../сhunk';
import { Table, ChunkId } from '../interface';
import { ChunkPool } from '../pool';
/**
 * InMemoryPool is a subset of ChunkPool abstraction
 * This pool saves rows in chunks that are stored in process memory
 *
 * @warning storing data in process memory can lead you to LOSS OF CONSISTANCE
 * but instead of this disadvantage you gain the cheapest and the most simple way to work
 * with clickhouse
 *
 * Data loss can only occur in two cases:
 * 1. When OS sends to a process SIGKILL code which is killing your process without grace
 * 2. When some piece of data contains anomalies such as `undefined` etc
 */
export declare class InMemoryPool extends ChunkPool {
    #private;
    /**
     * Create InMemoryPool instance
     */
    constructor();
    /**
     * Add new chunk to table set
     *
     * @param {Table} table table name
     * @param {Chunk} chunk ref
     */
    appendChunk(table: Table, chunk: Chunk): void;
    /**
     * Remove your chunk from table set
     *
     * @param {Table} table tableName
     * @param {ChunkId} id chunk unique id
     */
    removeChunk(table: Table, id: ChunkId): void;
    /**
     * Remove a list of chunks from table set
     *
     * @param {Table} table table name
     * @param {ChunkId[]} ids chunkk unique ids
     */
    removeChunks(table: Table, ids: ChunkId[]): void;
    /**
     * Get all current table chunks
     *
     * @param {Table} table table name
     * @returns {Chunk[]} list of chunks
     */
    getChunks(table: Table): Chunk[];
    /**
     * Get all current tables
     *
     * @returns {Table[]}
     */
    getTables(): Table[];
    /**
     * Get any unblocked chunk by now
     *
     * @param {Table} table table name
     * @returns {Chunk}
     */
    getUnblockedChunk(table: Table): Chunk;
}
