"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _InMemoryPool_instances, _InMemoryPool_chunks, _InMemoryPool_getAssertedTablePool;
Object.defineProperty(exports, "__esModule", { value: true });
exports.InMemoryPool = void 0;
const _hunk_1 = require("../\u0441hunk");
const pool_1 = require("../pool");
/**
 * InMemoryPool is a subset of ChunkPool abstraction
 * This pool saves rows in chunks that are stored in process memory
 *
 * @warning storing data in process memory can lead you to LOSS OF CONSISTANCE
 * but instead of this disadvantage you gain the cheapest and the most simple way to work
 * with clickhouse
 *
 * Data loss can only occur in two cases:
 * 1. When OS sends to a process SIGKILL code which is killing your process without grace
 * 2. When some piece of data contains anomalies such as `undefined` etc
 */
class InMemoryPool extends pool_1.ChunkPool {
    /**
     * Create InMemoryPool instance
     */
    constructor() {
        super();
        _InMemoryPool_instances.add(this);
        _InMemoryPool_chunks.set(this, void 0);
        __classPrivateFieldSet(this, _InMemoryPool_chunks, new Map(), "f");
    }
    /**
     * Add new chunk to table set
     *
     * @param {Table} table table name
     * @param {Chunk} chunk ref
     */
    appendChunk(table, chunk) {
        const tablePool = __classPrivateFieldGet(this, _InMemoryPool_instances, "m", _InMemoryPool_getAssertedTablePool).call(this, table);
        if (!tablePool.has(chunk)) {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            __classPrivateFieldGet(this, _InMemoryPool_chunks, "f").get(table).add(chunk);
        }
    }
    /**
     * Remove your chunk from table set
     *
     * @param {Table} table tableName
     * @param {ChunkId} id chunk unique id
     */
    removeChunk(table, id) {
        const tablePool = __classPrivateFieldGet(this, _InMemoryPool_instances, "m", _InMemoryPool_getAssertedTablePool).call(this, table);
        for (const chunk of tablePool.values()) {
            if (chunk.id === id) {
                tablePool.delete(chunk);
                break;
            }
        }
    }
    /**
     * Remove a list of chunks from table set
     *
     * @param {Table} table table name
     * @param {ChunkId[]} ids chunkk unique ids
     */
    removeChunks(table, ids) {
        const tablePool = __classPrivateFieldGet(this, _InMemoryPool_instances, "m", _InMemoryPool_getAssertedTablePool).call(this, table);
        for (const chunk of tablePool.values()) {
            if (ids.includes(chunk.id)) {
                tablePool.delete(chunk);
            }
        }
    }
    /**
     * Get all current table chunks
     *
     * @param {Table} table table name
     * @returns {Chunk[]} list of chunks
     */
    getChunks(table) {
        const tablePool = __classPrivateFieldGet(this, _InMemoryPool_instances, "m", _InMemoryPool_getAssertedTablePool).call(this, table);
        return [...tablePool.values()];
    }
    /**
     * Get all current tables
     *
     * @returns {Table[]}
     */
    getTables() {
        return [...__classPrivateFieldGet(this, _InMemoryPool_chunks, "f").keys()];
    }
    /**
     * Get any unblocked chunk by now
     *
     * @param {Table} table table name
     * @returns {Chunk}
     */
    getUnblockedChunk(table) {
        const tablePool = __classPrivateFieldGet(this, _InMemoryPool_instances, "m", _InMemoryPool_getAssertedTablePool).call(this, table);
        let firstUnblockedChunk;
        for (const chunk of tablePool.values()) {
            if (chunk.isUnblocked()) {
                firstUnblockedChunk = chunk;
                break;
            }
        }
        if (!firstUnblockedChunk) {
            firstUnblockedChunk = new _hunk_1.Chunk(table, this.getTtlMs());
            this.appendChunk(table, firstUnblockedChunk);
        }
        return firstUnblockedChunk;
    }
}
exports.InMemoryPool = InMemoryPool;
_InMemoryPool_chunks = new WeakMap(), _InMemoryPool_instances = new WeakSet(), _InMemoryPool_getAssertedTablePool = function _InMemoryPool_getAssertedTablePool(table) {
    if (!__classPrivateFieldGet(this, _InMemoryPool_chunks, "f").has(table)) {
        __classPrivateFieldGet(this, _InMemoryPool_chunks, "f").set(table, new Set());
    }
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    return __classPrivateFieldGet(this, _InMemoryPool_chunks, "f").get(table);
};
