import { ChunkId, InsertRow } from './interface';
/**
 * Chunk of a nasic item of this package
 *
 * Every chunk:
 * - has its unique id
 * - belongs to a table
 * - contain rows
 * - has size and time restrictions
 * - can be blocked/unblocked
 */
export declare class Chunk {
    #private;
    id: ChunkId;
    table: string;
    size: number;
    createdAt: number;
    expiresAt: number;
    blocked: boolean;
    /**
     * Create Chunk instance
     *
     * @param {string} table
     * @param {number} liveAtLeastMs
     */
    constructor(table: string, liveAtLeastMs: number);
    /**
     * Get state current state of expiration
     *
     * @returns {boolean}
     */
    isExpired(): boolean;
    /**
     * Get state of overvilling provided size limit
     *
     * @param {number} limit
     * @returns {boolean}
     */
    isOverfilled(limit: number): boolean;
    /**
     * Get state of block
     *
     * @returns {boolean}
     */
    isUnblocked(): boolean;
    /**
     * Trigger current chunk to become blocked, i.e. do not allow new row insertions
     */
    block(): void;
    /**
     * Trigger current chunk to become unblocked, i.e. allow new row insertions
     *
     */
    unblock(): void;
    /**
     * Get current chunk rows
     *
     * @returns {InsertRow[]}
     */
    getRows(): InsertRow[];
    /**
     * Add new rows to current chunk
     *
     * @param {InsertRow[]} rows
     */
    appendRows(rows: InsertRow[]): void;
}
