"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _Chunk_rows;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Chunk = void 0;
const cuid_1 = __importDefault(require("cuid"));
/**
 * Chunk of a nasic item of this package
 *
 * Every chunk:
 * - has its unique id
 * - belongs to a table
 * - contain rows
 * - has size and time restrictions
 * - can be blocked/unblocked
 */
class Chunk {
    /**
     * Create Chunk instance
     *
     * @param {string} table
     * @param {number} liveAtLeastMs
     */
    constructor(table, liveAtLeastMs) {
        _Chunk_rows.set(this, void 0);
        this.table = table;
        __classPrivateFieldSet(this, _Chunk_rows, [], "f");
        this.blocked = false;
        this.size = 0;
        this.id = `${table}_${Date.now().toString()}_${(0, cuid_1.default)()}`;
        this.createdAt = Date.now();
        this.expiresAt = this.createdAt + liveAtLeastMs;
    }
    /**
     * Get state current state of expiration
     *
     * @returns {boolean}
     */
    isExpired() {
        return Date.now() >= this.expiresAt;
    }
    /**
     * Get state of overvilling provided size limit
     *
     * @param {number} limit
     * @returns {boolean}
     */
    isOverfilled(limit) {
        return __classPrivateFieldGet(this, _Chunk_rows, "f").length >= limit;
    }
    /**
     * Get state of block
     *
     * @returns {boolean}
     */
    isUnblocked() {
        return !this.blocked;
    }
    /**
     * Trigger current chunk to become blocked, i.e. do not allow new row insertions
     */
    block() {
        this.blocked = true;
    }
    /**
     * Trigger current chunk to become unblocked, i.e. allow new row insertions
     *
     */
    unblock() {
        this.blocked = false;
    }
    /**
     * Get current chunk rows
     *
     * @returns {InsertRow[]}
     */
    getRows() {
        return __classPrivateFieldGet(this, _Chunk_rows, "f");
    }
    /**
     * Add new rows to current chunk
     *
     * @param {InsertRow[]} rows
     */
    appendRows(rows) {
        if (rows.length) {
            __classPrivateFieldGet(this, _Chunk_rows, "f").push(...rows);
            this.size += rows.length;
        }
    }
}
exports.Chunk = Chunk;
_Chunk_rows = new WeakMap();
